==> hatari_1.7.0.orig.tar.bz2: hatari-1.7.0/src/gui-sdl/font5x8.h <==
#define font5x8_width 80
#define font5x8_height 128
static const Uint8 font5x8_bits[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x10, 
  0x42, 0xDC, 0x57, 0x00, 0x00, 0x00, 0x00, 0x00, 0xC0, 0x11, 0x24, 0xEA, 
  0xAB, 0x00, 0x00, 0xE0, 0xDC, 0xDE, 0xA0, 0x92, 0xFF, 0xF7, 0x73, 0x00, 
  0x00, 0x10, 0x7F, 0xFC, 0x80, 0x54, 0x24, 0xF6, 0x75, 0x00, 0x00, 0x10, 
  0x3F, 0x70, 0x80, 0x38, 0x42, 0xEA, 0xAC, 0x00, 0x00, 0x10, 0x7F, 0xFC, 
  0x80, 0x10, 0x00, 0xDC, 0x56, 0x00, 0x00, 0xE0, 0xDC, 0xDE, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x45, 0x80, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x80, 0x28, 0xE5, 0x54, 0x21, 0x44, 0x00, 0x00, 0x00, 0x40, 
  0x80, 0xA8, 0x5F, 0x50, 0x21, 0x82, 0x24, 0x02, 0x00, 0x40, 0x80, 0x28, 
  0xE5, 0x88, 0x20, 0x82, 0x18, 0x02, 0x00, 0x20, 0x80, 0x80, 0x4F, 0x45, 
  0x01, 0x82, 0xBC, 0x0F, 0x1E, 0x10, 0x00, 0x00, 0xE5, 0x54, 0x01, 0x82, 
  0x18, 0xC2, 0x80, 0x09, 0x80, 0x00, 0x45, 0x80, 0x02, 0x44, 0x24, 0x42, 
  0x80, 0x09, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x8C, 0x98, 
  0x47, 0x9E, 0x79, 0xC6, 0x00, 0x80, 0x80, 0x20, 0xD2, 0x24, 0x62, 0x42, 
  0x40, 0x29, 0x19, 0x46, 0x00, 0x51, 0x9A, 0x20, 0x53, 0xCE, 0x21, 0x26, 
  0x19, 0x26, 0x1E, 0x42, 0x96, 0x18, 0xF4, 0x50, 0x22, 0xC9, 0x01, 0x20, 
  0x00, 0x22, 0x92, 0x84, 0x44, 0x52, 0x12, 0x09, 0x19, 0x46, 0x1E, 0x01, 
  0xCC, 0x3D, 0x43, 0x8C, 0x11, 0xC6, 0x18, 0x82, 0x80, 0x20, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xD2, 0x1C, 0x73, 0xDE, 0x33, 0xC9, 
  0xB9, 0x14, 0x54, 0x32, 0x39, 0xA5, 0x94, 0x42, 0x48, 0x89, 0x90, 0x12, 
  0xEA, 0x4A, 0x35, 0x9D, 0x90, 0xCE, 0x09, 0x8F, 0x90, 0x11, 0xEA, 0x4A, 
  0xF5, 0xA5, 0x90, 0x42, 0x68, 0x89, 0x90, 0x12, 0x62, 0x4B, 0x29, 0xA5, 
  0x94, 0x42, 0x48, 0x89, 0x94, 0x12, 0x62, 0x4B, 0x22, 0x1D, 0x73, 0x5E, 
  0x30, 0xC9, 0x89, 0xF4, 0x62, 0x32, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0xC7, 0x1C, 0xE3, 0x52, 0x52, 0x29, 0x3E, 0x17, 0x1C, 0x01, 
  0x29, 0xA5, 0x44, 0x52, 0x8A, 0x29, 0x22, 0x11, 0x90, 0x02, 0x29, 0x25, 
  0x41, 0x52, 0x8A, 0x46, 0x11, 0x21, 0x10, 0x00, 0x67, 0x1D, 0x42, 0x52, 
  0xAA, 0x86, 0x08, 0x41, 0x10, 0x00, 0xA1, 0xA5, 0x44, 0x92, 0xA9, 0x89, 
  0x04, 0x81, 0x10, 0x00, 0xC1, 0x24, 0x43, 0x8C, 0x51, 0x89, 0x3C, 0x87, 
  0x1C, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x04, 
  0x80, 0x00, 0x01, 0x81, 0xA0, 0x60, 0x00, 0x00, 0x04, 0x04, 0x80, 0x80, 
  0x02, 0x01, 0x80, 0x40, 0x00, 0x00, 0xC0, 0x1D, 0xE6, 0x8C, 0x30, 0xC7, 
  0xA0, 0x44, 0xD6, 0x31, 0x20, 0x25, 0x91, 0xDA, 0x49, 0x89, 0xA0, 0x43, 
  0x6A, 0x4A, 0x20, 0x25, 0x91, 0x86, 0x70, 0x89, 0xA0, 0x44, 0x6A, 0x4A, 
  0xC0, 0x1D, 0xE6, 0x8C, 0x40, 0xC9, 0xA9, 0xE4, 0x6A, 0x32, 0x00, 0x00, 
  0x00, 0x00, 0x30, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x06, 0x06, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 
  0x00, 0x41, 0x08, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x42, 
  0x84, 0x02, 0xC7, 0x15, 0x76, 0x92, 0x8A, 0x29, 0xBD, 0x41, 0x58, 0x01, 
  0x29, 0x2D, 0x23, 0x92, 0xAA, 0x26, 0x11, 0x42, 0x04, 0x00, 0xC7, 0x05, 
  0xA4, 0x92, 0xAA, 0xC6, 0x09, 0x41, 0x08, 0x00, 0x01, 0x05, 0x43, 0x1C, 
  0x51, 0x29, 0x3D, 0x46, 0x06, 0x00, 0x01, 0x01, 0x00, 0x00, 0x00, 0xC0, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x71, 0x00, 0x30, 0x00, 0x00, 0x00, 0x80, 0x00, 0x02, 0x22, 0x09, 0xCA, 
  0x29, 0x00, 0x80, 0x73, 0x00, 0x10, 0x15, 0x15, 0x39, 0xA0, 0x32, 0x00, 
  0xC0, 0x05, 0x80, 0xB8, 0xE3, 0x3E, 0x48, 0x60, 0x02, 0x05, 0xC0, 0x06, 
  0x80, 0x14, 0xA1, 0x08, 0x71, 0x60, 0xBA, 0xE2, 0xDC, 0x05, 0x80, 0x14, 
  0xE5, 0x3E, 0x41, 0xA0, 0x02, 0x85, 0xC0, 0x06, 0x80, 0xB8, 0x12, 0x09, 
  0x39, 0xC0, 0x01, 0x80, 0x80, 0x03, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x03, 0x00, 0x00, 0x80, 0x10, 0x10, 
  0x42, 0x00, 0x04, 0x28, 0x44, 0x80, 0x07, 0xC0, 0x28, 0x10, 0x82, 0x20, 
  0x8A, 0x20, 0x23, 0x40, 0x05, 0x80, 0x10, 0x10, 0x4A, 0x00, 0xC4, 0x11, 
  0x04, 0x52, 0x05, 0x80, 0x80, 0x52, 0x96, 0x21, 0x80, 0x38, 0x03, 0x92, 
  0x25, 0xC0, 0x39, 0x65, 0x50, 0x11, 0x00, 0x00, 0x00, 0x12, 0x05, 0x00, 
  0x80, 0xF2, 0xC8, 0x53, 0xC0, 0x01, 0x00, 0x0E, 0x05, 0x04, 0x00, 0x40, 
  0x1C, 0x21, 0x00, 0x00, 0x00, 0x02, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, 
  0x82, 0x18, 0x95, 0x0C, 0x00, 0x82, 0x98, 0x24, 0x10, 0x51, 0x44, 0xA4, 
  0x02, 0x92, 0x33, 0x44, 0x24, 0x40, 0x88, 0x02, 0xC6, 0x18, 0x63, 0x4C, 
  0x49, 0xEF, 0xBD, 0xE7, 0x9C, 0x73, 0x29, 0xA5, 0x94, 0x52, 0x09, 0x21, 
  0x84, 0x40, 0x08, 0x21, 0xEF, 0xBD, 0xF7, 0xDE, 0x0B, 0xE7, 0x9C, 0x43, 
  0x08, 0x21, 0x29, 0xA5, 0x94, 0x52, 0x49, 0x21, 0x84, 0x40, 0x08, 0x21, 
  0x29, 0xA5, 0x94, 0x52, 0x33, 0xEF, 0xBD, 0xE7, 0x9C, 0x73, 0x00, 0x00, 
  0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x09, 0x62, 0x54, 
  0x02, 0x40, 0x10, 0x93, 0x10, 0x00, 0xAE, 0x10, 0x91, 0x0A, 0x00, 0x8E, 
  0x88, 0x04, 0x48, 0x30, 0x32, 0x19, 0x63, 0x8C, 0x01, 0x2D, 0xA5, 0x94, 
  0xE2, 0x49, 0x77, 0xA5, 0x94, 0x52, 0x02, 0x2D, 0xA5, 0x94, 0x54, 0x2A, 
  0xB2, 0xA5, 0x94, 0x52, 0x52, 0x2B, 0xA5, 0x94, 0x48, 0x2A, 0x32, 0xA5, 
  0x94, 0x52, 0x22, 0x2B, 0xA5, 0x94, 0xC8, 0x49, 0x2E, 0x19, 0x63, 0x8C, 
  0x51, 0xC7, 0x18, 0x63, 0x48, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x82, 0x10, 0x05, 0x0C, 0x00, 0x82, 0x18, 0x20, 
  0x10, 0x01, 0x44, 0xA8, 0xA2, 0x12, 0x00, 0x44, 0x24, 0x45, 0x88, 0x52, 
  0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xCE, 0x39, 
  0xE7, 0xDC, 0x63, 0xC6, 0x18, 0x63, 0x8C, 0x31, 0x29, 0xA5, 0x94, 0x92, 
  0x15, 0xAD, 0xB5, 0x46, 0x08, 0x21, 0x29, 0xA5, 0x94, 0x52, 0x13, 0x63, 
  0x8C, 0x41, 0x08, 0x21, 0xCE, 0x39, 0xE7, 0x9C, 0x67, 0xC6, 0x18, 0xE3, 
  0x9C, 0x73, 0x00, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x45, 0x09, 0x62, 0x14, 0x00, 0x40, 0x10, 0x03, 0x08, 0x00, 0xA2, 0x10, 
  0x91, 0x4A, 0x02, 0x80, 0x88, 0x94, 0x44, 0x48, 0x05, 0x00, 0x00, 0x00, 
  0x20, 0x00, 0x00, 0x00, 0x40, 0x00, 0xE8, 0x18, 0x63, 0x8C, 0x01, 0x2E, 
  0xA5, 0x94, 0xD2, 0x49, 0x2E, 0xA5, 0x94, 0x52, 0x72, 0x2D, 0xA5, 0x94, 
  0x52, 0x4A, 0x29, 0xA5, 0x94, 0x52, 0x02, 0x2B, 0xA5, 0x94, 0xDC, 0x71, 
  0x26, 0x19, 0x63, 0x8C, 0x21, 0xC7, 0x39, 0xE7, 0x52, 0x48, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x4C, 0x30, };

==> hatari_2.1.0+dfsg.orig.tar.bz2: hatari-2.1.0/src/gui-sdl/font5x8.h <==
#define font5x8_width 80
#define font5x8_height 128
static const Uint8 font5x8_bits[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x10, 
  0x42, 0xDC, 0x57, 0x00, 0x00, 0x00, 0x00, 0x00, 0xC0, 0x11, 0x24, 0xEA, 
  0xAB, 0x00, 0x00, 0xE0, 0xDC, 0xDE, 0xA0, 0x92, 0xFF, 0xF7, 0x73, 0x00, 
  0x00, 0x10, 0x7F, 0xFC, 0x80, 0x54, 0x24, 0xF6, 0x75, 0x00, 0x00, 0x10, 
  0x3F, 0x70, 0x80, 0x38, 0x42, 0xEA, 0xAC, 0x00, 0x00, 0x10, 0x7F, 0xFC, 
  0x80, 0x10, 0x00, 0xDC, 0x56, 0x00, 0x00, 0xE0, 0xDC, 0xDE, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x45, 0x80, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x80, 0x28, 0xE5, 0x54, 0x21, 0x44, 0x00, 0x00, 0x00, 0x40, 
  0x80, 0xA8, 0x5F, 0x50, 0x21, 0x82, 0x24, 0x02, 0x00, 0x40, 0x80, 0x28, 
  0xE5, 0x88, 0x20, 0x82, 0x18, 0x02, 0x00, 0x20, 0x80, 0x80, 0x4F, 0x45, 
  0x01, 0x82, 0xBC, 0x0F, 0x1E, 0x10, 0x00, 0x00, 0xE5, 0x54, 0x01, 0x82, 
  0x18, 0xC2, 0x80, 0x09, 0x80, 0x00, 0x45, 0x80, 0x02, 0x44, 0x24, 0x42, 
  0x80, 0x09, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x8C, 0x98, 
  0x47, 0x9E, 0x79, 0xC6, 0x00, 0x80, 0x80, 0x20, 0xD2, 0x24, 0x62, 0x42, 
  0x40, 0x29, 0x19, 0x46, 0x00, 0x51, 0x9A, 0x20, 0x53, 0xCE, 0x21, 0x26, 
  0x19, 0x26, 0x1E, 0x42, 0x96, 0x18, 0xF4, 0x50, 0x22, 0xC9, 0x01, 0x20, 
  0x00, 0x22, 0x92, 0x84, 0x44, 0x52, 0x12, 0x09, 0x19, 0x46, 0x1E, 0x01, 
  0xCC, 0x3D, 0x43, 0x8C, 0x11, 0xC6, 0x18, 0x82, 0x80, 0x20, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xD2, 0x1C, 0x73, 0xDE, 0x33, 0xC9, 
  0xB9, 0x14, 0x54, 0x32, 0x39, 0xA5, 0x94, 0x42, 0x48, 0x89, 0x90, 0x12, 
  0xEA, 0x4A, 0x35, 0x9D, 0x90, 0xCE, 0x09, 0x8F, 0x90, 0x11, 0xEA, 0x4A, 
  0xF5, 0xA5, 0x90, 0x42, 0x68, 0x89, 0x90, 0x12, 0x62, 0x4B, 0x29, 0xA5, 
  0x94, 0x42, 0x48, 0x89, 0x94, 0x12, 0x62, 0x4B, 0x22, 0x1D, 0x73, 0x5E, 
  0x30, 0xC9, 0x89, 0xF4, 0x62, 0x32, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0xC7, 0x1C, 0xE3, 0x52, 0x52, 0x29, 0x3E, 0x17, 0x1C, 0x01, 
  0x29, 0xA5, 0x44, 0x52, 0x8A, 0x29, 0x22, 0x11, 0x90, 0x02, 0x29, 0x25, 
  0x41, 0x52, 0x8A, 0x46, 0x11, 0x21, 0x10, 0x00, 0x67, 0x1D, 0x42, 0x52, 
  0xAA, 0x86, 0x08, 0x41, 0x10, 0x00, 0xA1, 0xA5, 0x44, 0x92, 0xA9, 0x89, 
  0x04, 0x81, 0x10, 0x00, 0xC1, 0x24, 0x43, 0x8C, 0x51, 0x89, 0x3C, 0x87, 
  0x1C, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x04, 
  0x80, 0x00, 0x01, 0x81, 0xA0, 0x60, 0x00, 0x00, 0x04, 0x04, 0x80, 0x80, 
  0x02, 0x01, 0x80, 0x40, 0x00, 0x00, 0xC0, 0x1D, 0xE6, 0x8C, 0x30, 0xC7, 
  0xA0, 0x44, 0xD6, 0x31, 0x20, 0x25, 0x91, 0xDA, 0x49, 0x89, 0xA0, 0x43, 
  0x6A, 0x4A, 0x20, 0x25, 0x91, 0x86, 0x70, 0x89, 0xA0, 0x44, 0x6A, 0x4A, 
  0xC0, 0x1D, 0xE6, 0x8C, 0x40, 0xC9, 0xA9, 0xE4, 0x6A, 0x32, 0x00, 0x00, 
  0x00, 0x00, 0x30, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x06, 0x06, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 
  0x00, 0x41, 0x08, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x42, 
  0x84, 0x02, 0xC7, 0x15, 0x76, 0x92, 0x8A, 0x29, 0xBD, 0x41, 0x58, 0x01, 
  0x29, 0x2D, 0x23, 0x92, 0xAA, 0x26, 0x11, 0x42, 0x04, 0x00, 0xC7, 0x05, 
  0xA4, 0x92, 0xAA, 0xC6, 0x09, 0x41, 0x08, 0x00, 0x01, 0x05, 0x43, 0x1C, 
  0x51, 0x29, 0x3D, 0x46, 0x06, 0x00, 0x01, 0x01, 0x00, 0x00, 0x00, 0xC0, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x00, 
  0x80, 0x02, 0x0C, 0x00, 0x06, 0x00, 0x21, 0x04, 0x10, 0xA0, 0x01, 0x01, 
  0x12, 0x00, 0x0A, 0x80, 0x73, 0x0A, 0x32, 0x58, 0x80, 0x07, 0x07, 0x00, 
  0x07, 0x00, 0x21, 0x40, 0x09, 0x54, 0x00, 0x02, 0x07, 0x00, 0x02, 0x00, 
  0x21, 0x80, 0x30, 0xD2, 0x01, 0x01, 0x12, 0x00, 0x02, 0x00, 0x71, 0x40, 
  0x40, 0x54, 0x80, 0x00, 0x0C, 0xA0, 0xA2, 0x2A, 0x21, 0x80, 0x32, 0xA8, 
  0x81, 0x07, 0x00, 0x10, 0xA1, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x20, 
  0xA5, 0x00, 0x00, 0x54, 0x2B, 0x00, 0x00, 0x55, 0x00, 0x11, 0xA5, 0x00, 
  0x00, 0x4A, 0x13, 0x02, 0x00, 0x8A, 0x00, 0x00, 0x00, 0x18, 0x00, 0x40, 
  0x3B, 0xA4, 0x80, 0x57, 0x00, 0x00, 0x00, 0x98, 0xF3, 0x00, 0x18, 0xD8, 
  0x01, 0x22, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x54, 0x00, 0x21, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0xA2, 0x80, 0x27, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x71, 0x00, 0x30, 0x00, 0x00, 0x00, 0x80, 0x00, 0x02, 0x22, 0x09, 0xCA, 
  0x29, 0x00, 0x80, 0x73, 0x00, 0x10, 0x15, 0x15, 0x39, 0xA0, 0x32, 0x00, 
  0xC0, 0x05, 0x80, 0xB8, 0xE3, 0x3E, 0x48, 0x60, 0x02, 0x05, 0xC0, 0x06, 
  0x80, 0x14, 0xA1, 0x08, 0x71, 0x60, 0xBA, 0xE2, 0xDC, 0x05, 0x80, 0x14, 
  0xE5, 0x3E, 0x41, 0xA0, 0x02, 0x85, 0xC0, 0x06, 0x80, 0xB8, 0x12, 0x09, 
  0x39, 0xC0, 0x01, 0x80, 0x80, 0x03, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x03, 0x00, 0x00, 0x80, 0x10, 0x10, 
  0x42, 0x00, 0x04, 0x28, 0x44, 0x80, 0x07, 0xC0, 0x28, 0x10, 0x82, 0x20, 
  0x8A, 0x20, 0x23, 0x40, 0x05, 0x80, 0x10, 0x10, 0x4A, 0x00, 0xC4, 0x11, 
  0x04, 0x52, 0x05, 0x80, 0x80, 0x52, 0x96, 0x21, 0x80, 0x38, 0x03, 0x92, 
  0x25, 0xC0, 0x39, 0x65, 0x50, 0x11, 0x00, 0x00, 0x00, 0x12, 0x05, 0x00, 
  0x80, 0xF2, 0xC8, 0x53, 0xC0, 0x01, 0x00, 0x0E, 0x05, 0x04, 0x00, 0x40, 
  0x1C, 0x21, 0x00, 0x00, 0x00, 0x02, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, 
  0x82, 0x18, 0x95, 0x0C, 0x00, 0x82, 0x98, 0x24, 0x10, 0x51, 0x44, 0xA4, 
  0x02, 0x92, 0x33, 0x44, 0x24, 0x40, 0x88, 0x02, 0xC6, 0x18, 0x63, 0x4C, 
  0x49, 0xEF, 0xBD, 0xE7, 0x9C, 0x73, 0x29, 0xA5, 0x94, 0x52, 0x09, 0x21, 
  0x84, 0x40, 0x08, 0x21, 0xEF, 0xBD, 0xF7, 0xDE, 0x0B, 0xE7, 0x9C, 0x43, 
  0x08, 0x21, 0x29, 0xA5, 0x94, 0x52, 0x49, 0x21, 0x84, 0x40, 0x08, 0x21, 
  0x29, 0xA5, 0x94, 0x52, 0x33, 0xEF, 0xBD, 0xE7, 0x9C, 0x73, 0x00, 0x00, 
  0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x09, 0x62, 0x54, 
  0x02, 0x40, 0x10, 0x93, 0x10, 0x00, 0xAE, 0x10, 0x91, 0x0A, 0x00, 0x8E, 
  0x88, 0x04, 0x48, 0x30, 0x32, 0x19, 0x63, 0x8C, 0x01, 0x2D, 0xA5, 0x94, 
  0xE2, 0x49, 0x77, 0xA5, 0x94, 0x52, 0x02, 0x2D, 0xA5, 0x94, 0x54, 0x2A, 
  0xB2, 0xA5, 0x94, 0x52, 0x52, 0x2B, 0xA5, 0x94, 0x48, 0x2A, 0x32, 0xA5, 
  0x94, 0x52, 0x22, 0x2B, 0xA5, 0x94, 0xC8, 0x49, 0x2E, 0x19, 0x63, 0x8C, 
  0x51, 0xC7, 0x18, 0x63, 0x48, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x82, 0x10, 0x05, 0x0C, 0x00, 0x82, 0x18, 0x20, 
  0x10, 0x01, 0x44, 0xA8, 0xA2, 0x12, 0x00, 0x44, 0x24, 0x45, 0x88, 0x52, 
  0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xCE, 0x39, 
  0xE7, 0xDC, 0x63, 0xC6, 0x18, 0x63, 0x8C, 0x31, 0x29, 0xA5, 0x94, 0x92, 
  0x15, 0xAD, 0xB5, 0x46, 0x08, 0x21, 0x29, 0xA5, 0x94, 0x52, 0x13, 0x63, 
  0x8C, 0x41, 0x08, 0x21, 0xCE, 0x39, 0xE7, 0x9C, 0x67, 0xC6, 0x18, 0xE3, 
  0x9C, 0x73, 0x00, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x45, 0x09, 0x62, 0x14, 0x00, 0x40, 0x10, 0x03, 0x08, 0x00, 0xA2, 0x10, 
  0x91, 0x4A, 0x02, 0x80, 0x88, 0x94, 0x44, 0x48, 0x05, 0x00, 0x00, 0x00, 
  0x20, 0x00, 0x00, 0x00, 0x40, 0x00, 0xE8, 0x18, 0x63, 0x8C, 0x01, 0x2E, 
  0xA5, 0x94, 0xD2, 0x49, 0x2E, 0xA5, 0x94, 0x52, 0x72, 0x2D, 0xA5, 0x94, 
  0x52, 0x4A, 0x29, 0xA5, 0x94, 0x52, 0x02, 0x2B, 0xA5, 0x94, 0xDC, 0x71, 
  0x26, 0x19, 0x63, 0x8C, 0x21, 0xC7, 0x39, 0xE7, 0x52, 0x48, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x4C, 0x30, };
